/*******************************/
/* cte_sim MODEL PARAMETERS    */
/*******************************/


/* AVAILABLE MODELS */
/* ---------------- */

/* MODEL 0:
 * Dummy do-nothing mode for debugging purposes. 
 * The CCD frame is only shifted and written as SIGNED_SHORT
 */
 
/* MODEL 1: 
 * Simple CTE attenuation of signal. Only the CTE value is needed.
 */
#define CTE_VALUE 0.992

/* MODEL 2: (BROKEN !)
 * Advanced model by P. Bristow & A. Alexov (Oct 2002) 
 * Needed Parameters: */

#define R_ZERO	0.28	/* fraction of traps exposed at zero signal */
#define N_T		1		/* density of bulk state traps (Depending on trap trype and NIEL) */
#define N_SAT	100000	/* Saturation signal level */

/* MODEL 3:
 * You are supposed to use this model.
 */



/* TECHNICAL PARAMETERS */
/* -------------------- */

/* Specify the filename of the output file. */
#define OUTPUT_FILE_NAME "out.fit"


/* Specify the gain factor of the inputframe in e/ADU.
 * The program will internally convert the inputframe
 * to integer amount of electrons, do the algorithm
 * then convert the output frame back to ADUs.
 */
#define GAIN 1		/* e / ADU */


/* The overscan option clocks the CCD out with a specified
 * amount of extra virtual rows. Trapped electrons may then
 * have time to be reemitted, and can then be counted for the
 * CTE determination by the EPER method. Setting this 
 * value to zero disables the overscan function.
 */
#define OVERSCAN_Y 		25

/* For simulating a frame transfer CCD, set the next option to 1.
 * 0 will disable the function. Note that internally the CCD input 
 * frame size is doubled in y direction if it is a frame transfer ccd,
 * thus the frame is seeing twice as many traps as if it would have
 * been a non frame transfer CCD.
 */
#define FRAME_TRANSFER 	1 		/* 0 = DISABLED, 1 = ENABLED */

/* Clock timings are very important for CTE performance.
 * All values below should stated in microseconds (s).
 * This is the serial clock cycle, which is usally quite fast:
 */
#define T_SERIAL  		60

/* The clocking time of the parallel shifts should at least
 * be (y_size * T_SERIAL), unless binning is done (wich is not supported yet).
 * Value is in s. */
#define T_PARALLEL 		10000

/* The clocking time of the parallel frame transfer cycle. This parameter
 * is only used if FRAME_TRANSER is enabled, else it is ignored.
 * Usually this clock time is faster than T_PARALLEL and slower than
 * T_SERIAL. Value is in s.
 */
#define T_PARALLEL_FT 	1000


/* Choose the average trap density in terms of #traps pr. pixel.
 * Reasonable numbers are 0.1 - 10. Processing time will increase
 * for large values. The traps are homogenously distributed across the
 * entire CCD.
 */
#define N_T		0.1

/* Here you can select the inital state of the traps
 * 0 = all traps initally empty
 * 1 = traps are in thermal equiv. NOT SUPPORTED YET, instead traps are filled 50%
 * 2 = all traps are filled
 */
#define TRAP_INIT 1

/* PHYSICAL PARAMETERS */
/* ------------------- */

/* These are the most commen traps created by hadron radiation.
 * The values are only approximate, the litterature has some
 * ambiguity on the exact numbers. All energies are in MeV.
 */
#define ENERGY_PV 		0.44  		
#define ENERGY_OV 		0.168		// not used yet
#define ENERGY_VV 		0.3			// not used yet

/* SIGMA_XX is the electron cross section, and is related to the 
 * ability for a specific trap to capture an electron.
 * This must be expressed in terms of cm^2.
 */
#define SIGMA_PV		3.5e-15		
#define SIGMA_OV		000			// unused
#define SIGMA_VV		000			// unused

/* The entropy factor is depending on the trap type, and is
 * dimensionless. You may use it as a fitting parameter, 
 * should be in the order of unity. Set it to 1 if you dont know.
 */
#define ENTROPY_FACTOR_PV				1.43	
#define ENTROPY_FACTOR_OV				1		// unused
#define ENTROPY_FACTOR_VV				1		// unused

/* The CTE behaviour is very dependent on the temperature.
 * Usable range is 100 - 350 Kelvin.
 */
#define TEMPERATURE 	180

/* Here are some classical physical constants which are needed by the model
 * The electron mass is corrected for relativistic effects in by the
 * "EFFECTOVE_ELECTRON_MASS_FACTOR", which depends on the semiconductor type.
 */
#define BOLZMANNS_CONSTANT				1.3807e-23		/* J/K */
#define PLANCKS_CONSTANT				6.6262e-34		/* Js */
#define ELECTRON_MASS					9.102e-31		/* kg */
#define EFFECTIVE_ELECTRON_MASS_FACTOR	0.98			/* for Silicon */	
#define EV								1.6e-19			/* 1 eV = EV Joule */
#define PI 								3.1415927


/* The next lines are are the input parameters for the Fe-55 test frames.
 * Setting this to enabled, will override any possible inputfiles, and 
 * and generate a Fe-55 frame with the background of FE_BACKGROUND.
 * The size of the frame is FE_CCDXSIZE and FE_CCDYSIZE.
 * The Fe-55 signal can be varied itself, which is useful if you
 * want to investigate the behaviour of different sources.
 */

#define FE_TESTFRAME 	0			/* 0 = DISABLED, 1 = ENABLED */
#define FE_CCDXSIZE 	50
#define FE_CCDYSIZE 	50
#define FE_BACKGROUND 	100			/* background level in e- 	*/
#define FE_SIGNAL		1620		/* Signal level 1620 e- 	*/
/* FE_DENSITY is the amount of events pr. pixel.*/
#define FE_DENSITY		0.1			/* Useful range: 0.1 - 0.001 */


